==> scanbot_sdk-2.10.0.tar.gz: lib/json/barcode_configuration_json.dart <==
import 'dart:ui';

import 'package:scanbot_sdk/json/common_data.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

part 'barcode_configuration_json.g.dart';

@JsonSerializable(
    includeIfNull: false, createFactory: false, explicitToJson: true)
class BarcodeScannerJsonConfiguration {
  ///A version of the configuration object
  String? version;

  ///The configuration object should be applied for this screen
  String? screen;

  ///An optional array of barcode document formats that act as a detection filter. By default all supported document formats will be detected.
  List<BarcodeDocumentFormat>? acceptedDocumentFormats;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Background color of the detection overlay.
  Color? cameraOverlayColor;

  ///Background color of the detection overlay.
  CameraModule? cameraModule;

  ///The relative initial zoom level of the camera in the range [0,1], where 0 is zoomed out and 1 is zoomed in. Default value is 0.0.
  double? cameraZoomFactor;

  ///Whether the cancel button is hidden or not. iOS only.
  bool? cancelButtonHidden;

  ///String being displayed on the cancel button.
  String? cancelButtonTitle;

  ///String being displayed on the cancel button.
  EngineMode? engineMode;

  ///Title of the button that opens the screen where the user can allow the usage of the camera by the app.
  String? enableCameraButtonTitle;

  ///Text that will be displayed when the app is not allowed to use the camera, prompting the user to enable the usage of the camera.
  String? enableCameraExplanationText;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Foreground color of the detection overlay.
  Color? finderLineColor;

  ///Width of finder frame border. Default is 2.
  double? finderLineWidth;

  ///String being displayed as description.
  String? finderTextHint;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Foreground color of the description label.
  Color? finderTextHintColor;

  ///Aspect ratio of finder frame (width \ height), which is used to build actual finder frame. Default is 1 - it is a square frame, which is good for QR capturing.
  FinderAspectRatio? finderAspectRatio;

  ///Controls whether the flash toggle button is hidden or not.
  bool? flashButtonHidden;

  ///String being displayed on the flash button.
  String? flashButtonTitle;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Foreground color of the flash button when flash is off.
  Color? flashButtonInactiveColor;

  ///Whether flash is toggled on or off.
  bool? flashEnabled;

  ///Disables auto-focus and locks the lens at the specified focus lock lens position. Default value is false. iOS only. For Android, minFocusDistanceLock can be used.
  bool? focusLockEnabled;

  ///The position of the lens. Values can be between 0.0f (minimum focusing distance) and 1.0f (maximum focusing distance). The value will be clamped to [0.0f, 1.0f]. The default value is 0.0. iOS only. For Android, minFocusDistanceLock can be used.
  double? focusLockPosition;

  ///UI Interface orientation lock mode
  OrientationLockMode? orientationLockMode;

  ///Optional minimum required text length of the detected barcode. The default is 0 (setting is turned off). NOTE - This feature works on ITF barcodes only.
  int? minimumTextLength;

  ///Optional maximum text length of the detected barcode. The default is 0 (setting is turned off). NOTE - This feature works on ITF barcodes only.
  int? maximumTextLength;

  ///Lock focus distance withing minimum possible range
  bool? minFocusDistanceLock;

  ///Optional minimum required quiet zone on the barcode. Measured in modules (the size of minimal bar on the barcode). The default is 10. NOTE - This feature works on ITF barcodes only.
  int? minimum1DBarcodesQuietZone;

  ///With this option enabled, the scanner removes checks digits for UPC, EAN and MSI Plessey codes. Has no effect if both single and double digit MSI Plessey checksums are enabled. The default is `false`
  bool? stripCheckDigits;

  ///Whether scanner screen should make a sound on successful barcode or MRZ detection.
  bool? successBeepEnabled;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Background color of the top bar.
  Color? topBarBackgroundColor;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Foreground color of the cancel button.
  Color? topBarButtonsColor;

  ///Accepted barcode formats
  List<BarcodeFormat>? barcodeFormats;

  ///Controls whether buttons should use all capitals style, as defined by the Android Material Design. Defaults to TRUE. Android only.
  bool? useButtonsAllCaps;

  ///If `true`, replaces the cancel button in the top bar with a back arrow icon. The default value is FALSE. Android only.
  bool? replaceCancelButtonWithIcon;

  ///Preview mode of the camera. FILL_IN or FIT_IN. Default is FILL_IN. Android only
  CameraPreviewMode? cameraPreviewMode;

  ///The range of valid camera zoom factors. Default value is (1.0; 3.0). iOS only. For Android, minFocusDistanceLock can be used.
  ZoomRange? cameraZoomRange;

  ///Sets auto close timer in seconds. 0 = disabled and it is the default value. Android only
  int? autoCancelTimeout;

  ///When set to `true`, the scanner assumes that the barcode can be a GS1 barcode. Turn it off, if you don't want to see decoded FNC1 characters ("]C1" and ASCII char 29). The default value is `true`. NOTE - Currently works for CODE128 barcodes only!
  bool? gs1DecodingEnabled;

  ///The checksum algorithm for MSI Plessey barcodes. The default value is Mod10.
  MSIPlesseyChecksumAlgorithm? msiPlesseyChecksumAlgorithm;

  ///If `true`, enabled the mode which slightly decreases the scanning quality and the energy consumption, and increases the scanning speed. If `false` - mode is disabled. The default is `false`. Android only.
  bool? lowPowerMode;

  ///The expected density of QR codes in an image.
  CodeDensity? codeDensity;

  ///The type of barcode image generation.
  BarcodeImageGenerationType? barcodeImageGenerationType;

  ///Scanning delay after scanner appearance in seconds. Defaults to 0 secs.
  double? initialScanDelay;

  ///Freezes a preview after a scan for a given amount of seconds. Defaults to 0 secs. Android only.
  double? delayAfterScan;

  ///When this property is set to true, the zoom can be activated by double tapping somewhere in the receivers view. iOS only.
  bool? doubleTapToZoomEnabled;

  ///When this property is set to true, the zoom can be activated by a pinch gesture somewhere in the receivers view. iOS only.
  bool? pinchToZoomEnabled;

  ///Defines, if zooming in or out should be animated. iOS only.
  bool? shouldAnimateZooming;

  ///The selection overay configuration.
  SelectionOverlayConfiguration? overlayConfiguration;

  BarcodeScannerJsonConfiguration({
    this.version,
    this.screen,
    this.acceptedDocumentFormats,
    this.cameraOverlayColor,
    this.cameraModule,
    this.cameraZoomFactor,
    this.cancelButtonHidden,
    this.cancelButtonTitle,
    this.engineMode,
    this.enableCameraButtonTitle,
    this.enableCameraExplanationText,
    this.finderLineColor,
    this.finderLineWidth,
    this.finderTextHint,
    this.finderTextHintColor,
    this.finderAspectRatio,
    this.flashButtonHidden,
    this.flashButtonTitle,
    this.flashButtonInactiveColor,
    this.flashEnabled,
    this.focusLockEnabled,
    this.focusLockPosition,
    this.orientationLockMode,
    this.minimumTextLength,
    this.maximumTextLength,
    this.minFocusDistanceLock,
    this.minimum1DBarcodesQuietZone,
    this.stripCheckDigits,
    this.successBeepEnabled,
    this.topBarBackgroundColor,
    this.topBarButtonsColor,
    this.barcodeFormats,
    this.useButtonsAllCaps,
    this.replaceCancelButtonWithIcon,
    this.cameraPreviewMode,
    this.cameraZoomRange,
    this.autoCancelTimeout,
    this.gs1DecodingEnabled,
    this.msiPlesseyChecksumAlgorithm,
    this.lowPowerMode,
    this.codeDensity,
    this.barcodeImageGenerationType,
    this.initialScanDelay,
    this.delayAfterScan,
    this.doubleTapToZoomEnabled,
    this.pinchToZoomEnabled,
    this.shouldAnimateZooming,
    this.overlayConfiguration,
  });

  Map<String, dynamic> toJson() =>
      _$BarcodeScannerJsonConfigurationToJson(this);
}

==> scanbot_sdk-2.12.1.tar.gz: lib/json/barcode_configuration_json.dart <==
import 'dart:ui';

import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/json/common_data.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

part 'barcode_configuration_json.g.dart';

@JsonSerializable(
    includeIfNull: false, createFactory: false, explicitToJson: true)
class BarcodeScannerJsonConfiguration {
  ///A version of the configuration object
  String? version;

  ///The configuration object should be applied for this screen
  String? screen;

  ///An optional array of barcode document formats that act as a detection filter. By default all supported document formats will be detected.
  List<BarcodeDocumentFormat>? acceptedDocumentFormats;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Background color of the detection overlay.
  Color? cameraOverlayColor;

  ///Background color of the detection overlay.
  CameraModule? cameraModule;

  ///The relative initial zoom level of the camera in the range [0,1], where 0 is zoomed out and 1 is zoomed in. Default value is 0.0.
  double? cameraZoomFactor;

  ///Whether the cancel button is hidden or not. iOS only.
  bool? cancelButtonHidden;

  ///String being displayed on the cancel button.
  String? cancelButtonTitle;

  ///String being displayed on the cancel button.
  EngineMode? engineMode;

  ///Title of the button that opens the screen where the user can allow the usage of the camera by the app.
  String? enableCameraButtonTitle;

  ///Text that will be displayed when the app is not allowed to use the camera, prompting the user to enable the usage of the camera.
  String? enableCameraExplanationText;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Foreground color of the detection overlay.
  Color? finderLineColor;

  ///Width of finder frame border. Default is 2.
  double? finderLineWidth;

  ///String being displayed as description.
  String? finderTextHint;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Foreground color of the description label.
  Color? finderTextHintColor;

  ///Aspect ratio of finder frame (width \ height), which is used to build actual finder frame. Default is 1 - it is a square frame, which is good for QR capturing.
  FinderAspectRatio? finderAspectRatio;

  ///Controls whether the flash toggle button is hidden or not.
  bool? flashButtonHidden;

  ///String being displayed on the flash button.
  String? flashButtonTitle;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Foreground color of the flash button when flash is off.
  Color? flashButtonInactiveColor;

  ///Whether flash is toggled on or off.
  bool? flashEnabled;

  ///Disables auto-focus and locks the lens at the specified focus lock lens position. Default value is false. iOS only. For Android, minFocusDistanceLock can be used.
  bool? focusLockEnabled;

  ///The position of the lens. Values can be between 0.0f (minimum focusing distance) and 1.0f (maximum focusing distance). The value will be clamped to [0.0f, 1.0f]. The default value is 0.0. iOS only. For Android, minFocusDistanceLock can be used.
  double? focusLockPosition;

  ///UI Interface orientation lock mode
  OrientationLockMode? orientationLockMode;

  ///Optional minimum required text length of the detected barcode. The default is 0 (setting is turned off). NOTE - This feature works on ITF barcodes only.
  int? minimumTextLength;

  ///Optional maximum text length of the detected barcode. The default is 0 (setting is turned off). NOTE - This feature works on ITF barcodes only.
  int? maximumTextLength;

  ///Lock focus distance withing minimum possible range
  bool? minFocusDistanceLock;

  ///Optional minimum required quiet zone on the barcode. Measured in modules (the size of minimal bar on the barcode). The default is 10. NOTE - This feature works on ITF barcodes only.
  int? minimum1DBarcodesQuietZone;

  ///With this option enabled, the scanner removes checks digits for UPC, EAN and MSI Plessey codes. Has no effect if both single and double digit MSI Plessey checksums are enabled. The default is `false`
  bool? stripCheckDigits;

  ///Whether scanner screen should make a sound on successful barcode or MRZ detection.
  bool? successBeepEnabled;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Background color of the top bar.
  Color? topBarBackgroundColor;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)

  ///Foreground color of the cancel button.
  Color? topBarButtonsColor;

  ///Accepted barcode formats
  List<BarcodeFormat>? barcodeFormats;

  ///Controls whether buttons should use all capitals style, as defined by the Android Material Design. Defaults to TRUE. Android only.
  bool? useButtonsAllCaps;

  ///If `true`, replaces the cancel button in the top bar with a back arrow icon. The default value is FALSE. Android only.
  bool? replaceCancelButtonWithIcon;

  ///Preview mode of the camera. FILL_IN or FIT_IN. Default is FILL_IN. Android only
  CameraPreviewMode? cameraPreviewMode;

  ///The range of valid camera zoom factors. Default value is (1.0; 3.0). iOS only. For Android, minFocusDistanceLock can be used.
  ZoomRange? cameraZoomRange;

  ///Sets auto close timer in seconds. 0 = disabled and it is the default value. Android only
  int? autoCancelTimeout;

  ///When set to `true`, the scanner assumes that the barcode can be a GS1 barcode. Turn it off, if you don't want to see decoded FNC1 characters ("]C1" and ASCII char 29). The default value is `true`. NOTE - Currently works for CODE128 barcodes only!
  bool? gs1DecodingEnabled;

  ///The checksum algorithm for MSI Plessey barcodes. The default value is Mod10.
  MSIPlesseyChecksumAlgorithm? msiPlesseyChecksumAlgorithm;

  ///If `true`, enabled the mode which slightly decreases the scanning quality and the energy consumption, and increases the scanning speed. If `false` - mode is disabled. The default is `false`. Android only.
  bool? lowPowerMode;

  ///The expected density of QR codes in an image.
  CodeDensity? codeDensity;

  ///The type of barcode image generation.
  BarcodeImageGenerationType? barcodeImageGenerationType;

  ///Scanning delay after scanner appearance in seconds. Defaults to 0 secs.
  double? initialScanDelay;

  ///Freezes a preview after a scan for a given amount of seconds. Defaults to 0 secs. Android only.
  double? delayAfterScan;

  ///When this property is set to true, the zoom can be activated by double tapping somewhere in the receivers view. iOS only.
  bool? doubleTapToZoomEnabled;

  ///When this property is set to true, the zoom can be activated by a pinch gesture somewhere in the receivers view. iOS only.
  bool? pinchToZoomEnabled;

  ///Defines, if zooming in or out should be animated. iOS only.
  bool? shouldAnimateZooming;

  ///The selection overlay configuration.
  SelectionOverlayConfiguration? overlayConfiguration;

  BarcodeScannerJsonConfiguration({
    this.version,
    this.screen,
    this.acceptedDocumentFormats,
    this.cameraOverlayColor,
    this.cameraModule,
    this.cameraZoomFactor,
    this.cancelButtonHidden,
    this.cancelButtonTitle,
    this.engineMode,
    this.enableCameraButtonTitle,
    this.enableCameraExplanationText,
    this.finderLineColor,
    this.finderLineWidth,
    this.finderTextHint,
    this.finderTextHintColor,
    this.finderAspectRatio,
    this.flashButtonHidden,
    this.flashButtonTitle,
    this.flashButtonInactiveColor,
    this.flashEnabled,
    this.focusLockEnabled,
    this.focusLockPosition,
    this.orientationLockMode,
    this.minimumTextLength,
    this.maximumTextLength,
    this.minFocusDistanceLock,
    this.minimum1DBarcodesQuietZone,
    this.stripCheckDigits,
    this.successBeepEnabled,
    this.topBarBackgroundColor,
    this.topBarButtonsColor,
    this.barcodeFormats,
    this.useButtonsAllCaps,
    this.replaceCancelButtonWithIcon,
    this.cameraPreviewMode,
    this.cameraZoomRange,
    this.autoCancelTimeout,
    this.gs1DecodingEnabled,
    this.msiPlesseyChecksumAlgorithm,
    this.lowPowerMode,
    this.codeDensity,
    this.barcodeImageGenerationType,
    this.initialScanDelay,
    this.delayAfterScan,
    this.doubleTapToZoomEnabled,
    this.pinchToZoomEnabled,
    this.shouldAnimateZooming,
    this.overlayConfiguration,
  });

  Map<String, dynamic> toJson() =>
      _$BarcodeScannerJsonConfigurationToJson(this);
}
